Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrecht Van Lommel <brechtvanlommel@gmail.com>2019-07-01 17:51:00 +0300
committerBrecht Van Lommel <brechtvanlommel@gmail.com>2019-07-01 17:53:41 +0300
commitc6d073f6a4e7e455b5891359e65fdffbb74a0887 (patch)
tree8466f5cd3d897c233ff4b8111a0d61886558679b /source/blender/editors/object/object_add.c
parent510daea5455ad752ba2d9c97836bbcb54c8054ce (diff)
Revert "Rename operator 'Join Shapes' to 'Transfer Mix'."
This reverts commit 741967079c393a9eb6babd60c92a716fafa5d3e9. We are in UI and API freeze, and this changes both.
Diffstat (limited to 'source/blender/editors/object/object_add.c')
-rw-r--r--source/blender/editors/object/object_add.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/source/blender/editors/object/object_add.c b/source/blender/editors/object/object_add.c
index 468efc0c9d9..0fdb1cec16f 100644
--- a/source/blender/editors/object/object_add.c
+++ b/source/blender/editors/object/object_add.c
@@ -2782,10 +2782,10 @@ void OBJECT_OT_join(wmOperatorType *ot)
/** \} */
/* -------------------------------------------------------------------- */
/** \name Transfer Mix Operator for Shape Keys
* \{ */
-static bool shape_key_transfer_mix_poll(bContext *C)
+static bool join_shapes_poll(bContext *C)
{
Object *ob = CTX_data_active_object(C);
@@ -2802,12 +2802,12 @@ static bool shape_key_transfer_mix_poll(bContext *C)
}
}
-static int shape_key_transfer_mix_exec(bContext *C, wmOperator *op)
+static int join_shapes_exec(bContext *C, wmOperator *op)
{
Object *ob = CTX_data_active_object(C);
if (ob->mode & OB_MODE_EDIT) {
- BKE_report(op->reports, RPT_ERROR, "Shape Keys cannot be transfered in edit mode");
+ BKE_report(op->reports, RPT_ERROR, "This data does not support joining in edit mode");
return OPERATOR_CANCELLED;
}
else if (BKE_object_obdata_is_libdata(ob)) {
@@ -2822,16 +2822,16 @@ static int shape_key_transfer_mix_exec(bContext *C, wmOperator *op)
return OPERATOR_CANCELLED;
}
-void OBJECT_OT_shape_key_transfer_mix(wmOperatorType *ot)
+void OBJECT_OT_join_shapes(wmOperatorType *ot)
{
/* identifiers */
- ot->name = "Transfer Mix";
- ot->description = "Copy the current resulting shape of another selected object to this one";
- ot->idname = "OBJECT_OT_shape_key_transfer_mix";
+ ot->name = "Join as Shapes";
+ ot->description = "Merge selected objects to shapes of active object";
+ ot->idname = "OBJECT_OT_join_shapes";
/* api callbacks */
- ot->exec = shape_key_transfer_mix_exec;
- ot->poll = shape_key_transfer_mix_poll;
+ ot->exec = join_shapes_exec;
+ ot->poll = join_shapes_poll;
/* flags */
ot->flag = OPTYPE_REGISTER | OPTYPE_UNDO;
@@ -2782,10 +2782,10 @@ void OBJECT_OT_join(wmOperatorType *ot)
/** \} */
/* -------------------------------------------------------------------- */
-/** \name Transfer Mix Operator for Shape Keys
+/** \name Join as Shape Key Operator
* \{ */